@@ -142,7 +142,7 @@ function togglePreview(editor) {
         markdown_converter = Markdown.getSanitizingConverter().makeHtml;
     var wrapper = editor.getWrapperElement();
     var preview = document.getElementById('markdown_preview');
-    var btn = document.getElementsByClassName('preview_btn')[0];
+    var btn = document.getElementById('preview_btn');
     if (wrapper.style.display != 'none') {
         var text = markdown_converter(editor.getValue());
         preview.innerHTML = text;
@@ -204,6 +204,7 @@ function drawToolbar(editor) {
     preview.onclick = function(evt) {
         togglePreview(editor);
     }
+    preview.setAttribute('id', 'preview_btn');
     var preview_img = document.createElement('i');
     preview_img.className = 'fi-eye';
     preview.appendChild(preview_img);
